@@ -5,6 +5,7 @@ from hunger.forms import InviteSendForm
 from hunger.utils import setting, now
 from django.views.generic.base import TemplateView
 from django.views.generic.edit import FormView
+from django.contrib.auth.decorators import login_required
 
 
 class InviteView(FormView):
@@ -24,10 +25,6 @@ class InviteView(FormView):
 
         return super(InviteView, self).form_valid(form)
 
-    def form_invalid(self, form):
-        return super(InviteView, self).form_valid(form)
-
-
 class NotBetaView(TemplateView):
     """
     Display a message to the user after the invite request is completed
@@ -59,7 +56,9 @@ class InviteSentView(TemplateView):
     template_name = 'hunger/invite_sent.html'
 
 
+@login_required
 def verify_invite(request, code):
+    """Verify new invitee by storing invite code for middleware to validate."""
     response = redirect(setting('HUNGER_VERIFIED_REDIRECT'))
     response.set_cookie('hunger_code', code)
     return response
